<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>Predefiniti per nuovi disegni</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Default Linetype</source>
        <translation type="obsolete">Tipo di linea di default</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>Tipo di linea</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>Tipo di linea scala globale:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>La scala dei linetypes corrisponde alla scala di ogni viewport</translation>
    </message>
</context>
</TS>
